__version__ = '0.8a2'

import unittest
import xml.dom

import cssutils.css


class CSSStyleDeclarationTestCase(unittest.TestCase):

    def _set(self):
        self.s.setProperty(u'color', u'red')
        self.s.setProperty(u'left', u'5px', u'!important')


    def setUp(self):
        self.s = cssutils.css.CSSStyleDeclaration()

        
    def test_init(self):
        # TODO!
        self.assertEqual(0, self.s.length)


    def test_set_property(self):
        self.s.setProperty(u'color', u'red')
        self.s.setProperty(u'left', u'5px')
        self.s.setProperty(u'ANY', u'ANY')
        self.assertEqual(3, self.s.length)


        self.s.setProperty(u'content', u'";"')
        # raises only if syntax error


    def test_set_value(self):
        self.s.setProperty(u'color', u'green')
        self.s.setProperty(u'color', u'#0f0')
        self.s.setProperty(u'color', u'#00ff00')
        self.s.setProperty(u'color', u'RGB(0, 255, 0)')
        self.s.setProperty(u'ANY', u'ANY')
        self.assertEqual(2, self.s.length)

        self.assertRaises(xml.dom.SyntaxErr,
            self.s.setProperty, u'color', u'')
        self.assertRaises(xml.dom.SyntaxErr,
            self.s.setProperty, u'color', u'1px')
        self.assertRaises(xml.dom.SyntaxErr,
            self.s.setProperty, u'color', u'!important')


    def test_set_priority(self):
        self.s.setProperty(u'color', u'green')
        self.s.setProperty(u'color', u'green', u'')
        self.s.setProperty(u'color', u'green', u'!important')
        self.assertEqual(1, self.s.length)

        self.assertRaises(xml.dom.SyntaxErr,
            self.s.setProperty, u'color', u'red', u'XXXXXXX')
        self.assertRaises(xml.dom.SyntaxErr,
            self.s.setProperty, u'color', u'red', u'!x')


    def test_cssText(self):
        self.assertEqual(u'', self.s.cssText)
        self._set()
        self.assertEqual(u'    color: red;\n    left: 5px !important;',
                         self.s.cssText)

        s = cssutils.css.CSSStyleDeclaration()

        s.cssText = u'''content: ";";'''
        self.assertEqual(u'    content: ";";',
                         s.cssText)

        s.cssText = u'''content: ';';'''
        self.assertEqual(u'''    content: ';';''',
                         s.cssText)

        s.cssText = u'''content: "\"";'''
        self.assertEqual(u'''    content: "\"";''',
                         s.cssText)

    def test_get(self):
        self._set()
        # dom -> string
        self.assertEqual(u'', self.s.getPropertyValue(u''))
        self.assertEqual(u'', self.s.getPropertyValue(u'test'))

        self.assertEqual(u'red', self.s.getPropertyValue(u'color'))
        self.assertEqual(u'5px', self.s.getPropertyValue(u'left'))

        self.assertEqual(u'red',
                         self.s.getPropertyCSSValue(u'color').cssText)
        self.assertEqual(u'5px',
                         self.s.getPropertyCSSValue(u'left').cssText)
        self.assertEqual(None, self.s.getPropertyCSSValue(u'test'))

        # test shorthand property

        self.assertEqual(u'', self.s.getPropertyPriority(u'color'))
        self.assertEqual(u'!important', self.s.getPropertyPriority(u'left'))
        self.assertEqual(u'', self.s.getPropertyPriority(u'test'))
        self.assertEqual(u'', self.s.getPropertyPriority(u''))


    def test_item(self):
        self._set()
        self.assertEqual(u'color', self.s.item(0))
        self.assertEqual(u'left', self.s.item(1))
        self.assertEqual(u'', self.s.item(2))
        

    def test_remove(self):
        self._set()
        self.assertEqual(u'', self.s.removeProperty(''))
        self.assertEqual(2, self.s.length)
        self.assertEqual(u'red', self.s.removeProperty(u'color'))
        self.assertEqual(1, self.s.length)
        self.assertEqual(u'5px', self.s.removeProperty(u'left'))
        self.assertEqual(0, self.s.length)
        self.assertEqual(u'', self.s.removeProperty(u'test'))
        self.assertEqual(0, self.s.length)


if __name__ == '__main__':
    unittest.main() 